pub fn frame_tick()Expand description
Advance the frame counter.
Needed only by a VBlank handler that replaced the one this module installs.
pub fn frame_tick()Advance the frame counter.
Needed only by a VBlank handler that replaced the one this module installs.